'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.makeMediaBreakpointStyles = makeMediaBreakpointStyles;

var _makeColClasses = require('./makeColClasses');

var _makeOrderClasses = require('./makeOrderClasses');

var _makeOffsetClasses = require('./makeOffsetClasses');

var _getInfix = require('../utils/getInfix');

/**
 * Generate all the column CSS for a given breakpoint.
 * @param {string} breakpoint The current breakpoint.
 * @param {number} gridColumns The number of grid column units.
 * @param {Object} gridBreakpoints The gridBreakpoint option data.
 * @param {bool} doOrderClasses Whether to generate order classes.
 * @param {bool} doOffsetClasses Whether to generate offset classes.
 * @return {string} The generated CSS.
 */
function makeMediaBreakpointStyles({
    breakpoint,
    gridColumns,
    gridBreakpoints,
    doOrderClasses,
    doOffsetClasses
}) {
    const infix = (0, _getInfix.getInfix)(breakpoint);
    const output = `.col${infix} {
  flex-basis: 0;
  flex-grow: 1;
  max-width: 100%;
}

.col${infix}-auto {
  flex: 0 0 auto;
  width: auto;
  max-width: none;
}

${(0, _makeColClasses.makeColClasses)({ infix, gridColumns })}${(0, _makeOrderClasses.makeOrderClasses)({
        infix,
        gridColumns,
        doOrderClasses
    })}${(0, _makeOffsetClasses.makeOffsetClasses)({ infix, gridColumns, doOffsetClasses })}`;

    return breakpoint === '' ? output : `@media screen and (min-width: ${gridBreakpoints[breakpoint]}) {
${output}
}
`;
}