'use strict';

var _postcss = require('postcss');

var _postcss2 = _interopRequireDefault(_postcss);

var _cssbeautify = require('cssbeautify');

var _cssbeautify2 = _interopRequireDefault(_cssbeautify);

var _validateOpts = require('./validateOpts');

var _makeContainerClass = require('./makeContainerClass');

var _makeContainerMaxWidths = require('./makeContainerMaxWidths');

var _makeRowClass = require('./makeRowClass');

var _makeNoGuttersUtil = require('./makeNoGuttersUtil');

var _columns = require('./columns');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const makeGrid = (pluginOpts = {}) => new Promise((resolve, reject) => {
    (0, _validateOpts.validateOpts)(pluginOpts).then(opts => {
        resolve((0, _cssbeautify2.default)(`

      ${(0, _makeContainerClass.makeContainerClass)(opts)}
      ${(0, _makeContainerMaxWidths.makeContainerMaxWidths)(opts)}
      ${(0, _makeRowClass.makeRowClass)(opts)}
      ${(0, _makeNoGuttersUtil.makeNoGuttersUtil)()}
      ${(0, _columns.makeGridColumns)(opts)}

            `, {
            indent: '  ',
            autosemicolon: true
        }));
    }).catch(error => {
        reject(error);
    });
});

const bootstrap4Grid = (opts = {}) => root => new Promise((resolve, reject) => {
    root.walkAtRules('bootstrap-4-grid', rule => {
        makeGrid(opts).then(css => {
            rule.before(css);
            rule.remove();
            resolve();
        }).catch(error => {
            reject(error);
        });
    });
});

module.exports = _postcss2.default.plugin('bootstrap-4-grid', bootstrap4Grid);